@@ -144,6 +144,15 @@ def text_to_dict(
     return d
 
 
+def headers_str_to_dict(
+    cookies: str, 
+    /, 
+    kv_sep: str | Pattern[str] = ": ", 
+    entry_sep: str | Pattern[str] = "\n", 
+) -> dict[str, str]:
+    return text_to_dict(cookies.strip(), kv_sep, entry_sep)
+
+
 def cookies_str_to_dict(
     cookies: str, 
     /, 
@@ -166,8 +175,8 @@ class Client:
 
     def __init__(self, cookie: Optional[str] = None):
         session = self.session = Session()
-        # BDUSS, STOKEN
-        if not cookie or "BAIDUID=" not in cookie:
+        session.headers["User-Agent"] = "pan.baidu.com"
+        if not cookie or "BDUSS=" not in cookie:
             self.login_with_qrcode()
             self.request("https://pan.baidu.com/disk/main")
         else:
@@ -176,7 +185,12 @@ class Client:
         self.bdstoken = resp["result"]["bdstoken"]
         #self.logid = b64encode(self.session.cookies["BAIDUID"].encode("ascii")).decode("ascii")
 
-    def login_with_qrcode(self, /, scan_in_console=True):
+    def login_with_qrcode(
+        self, 
+        /, 
+        scan_in_console: bool = True, 
+        check: bool = True, 
+    ) -> dict:
         "扫描二维码登录"
         gid = str(uuid4()).upper()
         resp = self.get_qrcode(gid)
@@ -206,11 +220,13 @@ class Client:
                     pass
                 case _:
                     raise OSError(msg)
-
-        return self.request(
-            "https://passport.baidu.com/v3/login/main/qrbdusslogin?bduss={channel_v['v']}", 
+        resp = self.request(
+            f"https://passport.baidu.com/v3/login/main/qrbdusslogin?bduss={channel_v['v']}", 
             parse=eval, 
         )
+        if check and resp["errInfo"]["no"] not in ("0", 0):
+            raise OSError(resp)
+        return resp
 
     def request(
         self, 
@@ -422,9 +438,9 @@ class Client:
         if isinstance(data, (int, str)):
             data = {"fsidlist": "[%s]" % data, "path": "/"}
         elif isinstance(data, (list, tuple)):
-            data = {"fsidlist": "[%s]" % ", ".join(map(str, data)), "path": "/"}
+            data = {"fsidlist": "[%s]" % ",".join(map(str, data)), "path": "/"}
         elif isinstance(data["fsidlist"], (list, tuple)):
-            data["fsidlist"] = "[%s]" % ", ".join(map(str, data))
+            data["fsidlist"] = "[%s]" % ",".join(map(str, data["fsidlist"]))
         return self.request(api, "POST", params=params, data=data, headers={"Referer": url})
 
 
@@ -566,3 +582,6 @@ class ShareList:
             params["num"] = 100
         return Error.check(session.get(api, params=params).json())["list"]
 
+
+# TODO: 上传下载使用百度网盘的openapi，直接使用 alist 已经授权的 token
+
